@@ -40,8 +40,8 @@ public:
         FailedToStop = 2
     };
 
-    explicit KSMServer(QObject *parent = Q_NULLPTR);
-    virtual ~KSMServer();
+    explicit KSMServer(QObject *parent = nullptr);
+    ~KSMServer() override;
 
 public Q_SLOTS:
     void startActivitySession(const QString &activity);
